@@ -14,6 +14,7 @@ CONTENT_TYPES: Final = {
 
 COLOR_TABLE_COLUMN_1 = "#00ffff"
 COLOR_TABLE_COLUMN_2 = "#00ff00"
+WARNING = "#fffc00"
 
 PROMPT_STYLE: Final = Style.from_dict(
     {
@@ -23,6 +24,14 @@ PROMPT_STYLE: Final = Style.from_dict(
     },
 )
 
+PROMPT_STYLE_WARNING: Final = Style.from_dict(
+    {
+        # We use our table color scheme to match
+        "prompt": WARNING,  # Prompt is yellow
+        "": WARNING,  # User input is yellow
+    },
+)
+
 
 def prompt(sub_levels: tuple[str] | None = ()) -> str:
     """Render a command prompt to any number of 'levels'.
@@ -45,19 +54,23 @@ def make_italic(str_):
     return f"[italic]{str_}[/italic]"
 
 
-def options_as_help(options: list[str]) -> str:
+def options_as_help(options: list[str], depth: int = 1) -> str:
     """Return the list of options in a nice format for display.
 
-    Input options might be: ["AnAction", "SomethingElse", "Done"]
-    ..first, convert to     ["(A)nAction", "(S)omethingElse", "(D)one"]
-    ..finally, render using ["[italic](A)nAction[/italic]", etc.]
+    Input options might be: ["Action"  , "SomethingElse"  , "Done"]
+    first, we convert to    ["(A)ction", "(S)omethingElse", "(D)one"]
+    then we render to      "[italic](A)nAction[/italic], "
+
+    Similarly, when called with: ["title", "tag", "back"] AND depth of *2*:
+    we convert to                ["(ti)tle", "(ta)g", "(b)ack"]
+    and then render to          "[italic](ti)tle[/italic] [italic](ta)g[/italic]..."
     """
-    first_letters = [f"({option[0]}){option[1:]}" for option in options]
-    return ", ".join([make_italic(option) for option in first_letters])
+    initial_letters = [f"({option[0:depth]}){option[depth:]}" for option in options]
+    return ", ".join([make_italic(option) for option in initial_letters])
 
 
 def goodbye(console) -> None:
-    """Called on successful exit from any command/event-loop."""
+    """Print a nice thank you message on successful exit from any command/event-loop."""
     console.print(
         "[italic]Thanks, Gracias, Merci, Danka, ありがとう, спасибо, Köszönöm...![/]\n",
     )
